==> qtjambi-qml-debuginfo-macos-6.8.1.jar: sources/QtJambiQml/QQmlPropertyValueSource_shell.cpp <==
#include "QQmlPropertyValueSource_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlPropertyValueSource(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlPropertyValueSource")
    QQmlPropertyValueSource *_ptr = reinterpret_cast<QQmlPropertyValueSource *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlPropertyValueSource_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlPropertyValueSource_shell) ); }

jmethodID QQmlPropertyValueSource_oshell::__shell_javaMethod(int pos) const { return QQmlPropertyValueSource_shell::__shell()->javaMethod(typeid(QQmlPropertyValueSource), pos); }

// emitting (writeShellDestructor)
QQmlPropertyValueSource_shell::~QQmlPropertyValueSource_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlPropertyValueSource::~QQmlPropertyValueSource()", this)
    QQmlPropertyValueSource_shell::__shell()->destructed(typeid(QQmlPropertyValueSource));
}

// emitting (writeShellConstructor)
QQmlPropertyValueSource_shell::QQmlPropertyValueSource_shell()
    : QQmlPropertyValueSource()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlPropertyValueSource::QQmlPropertyValueSource_shell()", this)
    QQmlPropertyValueSource_shell::__shell()->constructed(typeid(QQmlPropertyValueSource));
}

void QQmlPropertyValueSource_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlPropertyValueSource_oshell*>(ptr)->QQmlPropertyValueSource_oshell::__shell()->tryDeleteShell(typeid(QQmlPropertyValueSource));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlPropertyValueSource_oshell::setTarget(const QQmlProperty& arg__1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlPropertyValueSource::setTarget(QQmlProperty)", this)
        if (JniEnvironmentExceptionHandler __jni_env{300}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlPropertyValueSource_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_arg__1 = qtjambi_cast<jobject>(__jni_env, arg__1);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_arg__1);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlPropertyValueSource_shell::__shell()->warnForMethod("QQmlPropertyValueSource::setTarget(QQmlProperty)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QQmlPropertyValueSource::setTarget(QQmlProperty)");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlPropertyValueSource_access::__qt_setTarget_cref_QQmlProperty(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const QQmlProperty& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QQmlProperty>(arg__1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlPropertyValueSource::setTarget(const QQmlProperty & arg__1)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlPropertyValueSource::setTarget(const QQmlProperty & arg__1).";
    } else {
        setTarget(__qt_arg__1);
    }
}

// emitting (writeConstructors)
// new QQmlPropertyValueSource()
void __qt_construct_QQmlPropertyValueSource(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlPropertyValueSource()")
    Q_UNUSED(__java_arguments)
    QQmlPropertyValueSource *__qt_this = new(__qtjambi_ptr) QQmlPropertyValueSource_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlPropertyValueSource::QQmlPropertyValueSource()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlPropertyValueSource_00024Impl_initialize_1native__Lio_qt_qml_QQmlPropertyValueSource_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlPropertyValueSource::QQmlPropertyValueSource()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlPropertyValueSource, sizeof(QQmlPropertyValueSource_shell), typeid(QQmlPropertyValueSource), 0, true, &deleter_QQmlPropertyValueSource, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlPropertyValueSource_shell
void __qt_destruct_QQmlPropertyValueSource(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlPropertyValueSource")
    reinterpret_cast<QQmlPropertyValueSource_shell*>(ptr)->~QQmlPropertyValueSource_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlPropertyValueSource::setTarget(QQmlProperty)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlPropertyValueSource_00024Impl_00024ConcreteWrapper_setTarget_1native_1cref_1QQmlProperty__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    QTJAMBI_TRY {
        QQmlPropertyValueSource *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlPropertyValueSource>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlPropertyValueSource::setTarget(QQmlProperty)", __this_nativeId)
        static_cast<QQmlPropertyValueSource_access*>(__qt_this)->__qt_setTarget_cref_QQmlProperty(__jni_env, __this_nativeId, arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlPropertyValueSource(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlPropertyValueSource>("QQmlPropertyValueSource", "io/qt/qml/QQmlPropertyValueSource");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo{/* 0 */ "setTarget", "(Lio/qt/qml/QQmlProperty;)V", FunctionInfo::Abstract}});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlPropertyValueSource, {
        ConstructorInfo{&__qt_construct_QQmlPropertyValueSource, nullptr}
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlPropertyValueSource);
    registerSizeOfShell(typeId, sizeof(QQmlPropertyValueSource_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlPropertyValueSource* _object = dynamic_cast<QQmlPropertyValueSource*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlPropertyValueSource *object = reinterpret_cast<QQmlPropertyValueSource *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlPropertyValueSource *object = reinterpret_cast<const QQmlPropertyValueSource *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.8.5.jar: sources/QtJambiQml/QQmlPropertyValueSource_shell.cpp <==
#include "QQmlPropertyValueSource_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlPropertyValueSource(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlPropertyValueSource")
    QQmlPropertyValueSource *_ptr = reinterpret_cast<QQmlPropertyValueSource *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlPropertyValueSource_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlPropertyValueSource_shell) ); }

jmethodID QQmlPropertyValueSource_oshell::__shell_javaMethod(int pos) const { return QQmlPropertyValueSource_shell::__shell()->javaMethod(typeid(QQmlPropertyValueSource), pos); }

// emitting (writeShellDestructor)
QQmlPropertyValueSource_shell::~QQmlPropertyValueSource_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlPropertyValueSource::~QQmlPropertyValueSource()", this)
    QQmlPropertyValueSource_shell::__shell()->destructed(typeid(QQmlPropertyValueSource));
}

// emitting (writeShellConstructor)
QQmlPropertyValueSource_shell::QQmlPropertyValueSource_shell()
    : QQmlPropertyValueSource()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlPropertyValueSource::QQmlPropertyValueSource_shell()", this)
    QQmlPropertyValueSource_shell::__shell()->constructed(typeid(QQmlPropertyValueSource));
}

void QQmlPropertyValueSource_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlPropertyValueSource_oshell*>(ptr)->QQmlPropertyValueSource_oshell::__shell()->tryDeleteShell(typeid(QQmlPropertyValueSource));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlPropertyValueSource_oshell::setTarget(const QQmlProperty& arg__1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlPropertyValueSource::setTarget(QQmlProperty)", this)
        if (JniEnvironmentExceptionHandler __jni_env{300}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlPropertyValueSource_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_arg__1 = qtjambi_cast<jobject>(__jni_env, arg__1);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_arg__1);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlPropertyValueSource_shell::__shell()->warnForMethod("QQmlPropertyValueSource::setTarget(QQmlProperty)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, this, "QQmlPropertyValueSource::setTarget(QQmlProperty)");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlPropertyValueSource_access::__qt_setTarget_cref_QQmlProperty(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const QQmlProperty& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QQmlProperty>(arg__1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlPropertyValueSource::setTarget(const QQmlProperty & arg__1)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlPropertyValueSource::setTarget(const QQmlProperty & arg__1).";
    } else {
        setTarget(__qt_arg__1);
    }
}

// emitting (writeConstructors)
// new QQmlPropertyValueSource()
void __qt_construct_QQmlPropertyValueSource(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlPropertyValueSource()")
    Q_UNUSED(__java_arguments)
    QQmlPropertyValueSource *__qt_this = new(__qtjambi_ptr) QQmlPropertyValueSource_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlPropertyValueSource::QQmlPropertyValueSource()
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlPropertyValueSource_00024Impl_initialize_1native__Lio_qt_qml_QQmlPropertyValueSource_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlPropertyValueSource::QQmlPropertyValueSource()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlPropertyValueSource, sizeof(QQmlPropertyValueSource_shell), typeid(QQmlPropertyValueSource), 0, true, &deleter_QQmlPropertyValueSource, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlPropertyValueSource_shell
void __qt_destruct_QQmlPropertyValueSource(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlPropertyValueSource")
    reinterpret_cast<QQmlPropertyValueSource_shell*>(ptr)->~QQmlPropertyValueSource_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlPropertyValueSource::setTarget(QQmlProperty)
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlPropertyValueSource_00024Impl_00024ConcreteWrapper_setTarget_1native_1cref_1QQmlProperty__JJ
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    QTJAMBI_TRY {
        QQmlPropertyValueSource *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlPropertyValueSource>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlPropertyValueSource::setTarget(QQmlProperty)", __this_nativeId)
        static_cast<QQmlPropertyValueSource_access*>(__qt_this)->__qt_setTarget_cref_QQmlProperty(__jni_env, __this_nativeId, arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlPropertyValueSource(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlPropertyValueSource>("QQmlPropertyValueSource", "io/qt/qml/QQmlPropertyValueSource");
    registerFunctionInfos(typeId, {
        FunctionInfo{/* 0 */ "setTarget", "(Lio/qt/qml/QQmlProperty;)V", FunctionInfo::Abstract}});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlPropertyValueSource, {
        ConstructorInfo{&__qt_construct_QQmlPropertyValueSource, nullptr}
    });
    registerDeleter(typeId, &deleter_QQmlPropertyValueSource);
    registerSizeOfShell(typeId, sizeof(QQmlPropertyValueSource_shell));
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlPropertyValueSource* _object = dynamic_cast<QQmlPropertyValueSource*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlPropertyValueSource *object = reinterpret_cast<QQmlPropertyValueSource *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlPropertyValueSource *object = reinterpret_cast<const QQmlPropertyValueSource *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
}
